// Copyright 2014 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/push_messaging/push_messaging_constants.h"

const char kPushMessagingGcmEndpoint[] =
    "https://fcm.googleapis.com/fcm/send/";

const char kPushMessagingStagingGcmEndpoint[] =
    "https://jmt17.google.com/fcm/send/";

const char kPushMessagingWebpushEndpoint[] =
    "https://fcm.googleapis.com/wp/";

const char kPushMessagingStagingWebpushEndpoint[] =
    "https://fcm.googleapis.com/preprod/wp/";

const char kPushMessagingForcedNotificationTag[] =
    "user_visible_auto_notification";
